import React, { useState, useRef, useEffect, createRef } from 'react';
import useInterval from '@use-it/interval';
import PropTypes from 'prop-types';
import scrollIntoView from 'scroll-into-view';
import { motion } from 'framer-motion';
import 'body-scroll-lock';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var styles = {"carousel":"_1ruxe","carousel-items":"_2KlPN","vertical":"_3Q84j","carousel-item":"_uRvDV","tracker":"_21UuF","dot":"_FMZUB","active":"_3P0rP"};

var SleekCarousel = function SleekCarousel(_ref) {
  var activeInitial = _ref.active,
      onTransitionStart = _ref.onTransitionStart,
      onTransitionOver = _ref.onTransitionOver,
      onTransitionEnd = _ref.onTransitionEnd,
      height = _ref.height,
      children = _ref.children,
      disableTracker = _ref.disableTracker,
      containerClassName = _ref.containerClassName,
      containerStyle = _ref.containerStyle,
      className = _ref.className,
      style = _ref.style,
      itemContainerClassName = _ref.itemContainerClassName,
      itemContainerStyle = _ref.itemContainerStyle,
      trackerClassName = _ref.trackerClassName,
      trackerStyle = _ref.trackerStyle,
      trackerDotClassName = _ref.trackerDotClassName,
      trackerDotStyle = _ref.trackerDotStyle,
      trackerDotActiveClassName = _ref.trackerDotActiveClassName,
      trackerDotActiveStyle = _ref.trackerDotActiveStyle,
      vertical = _ref.vertical,
      delay = _ref.delay,
      speed = _ref.speed,
      disableScroll = _ref.disableScroll,
      looping = _ref.looping,
      relay = _ref.relay,
      panning = _ref.panning;
  var TOTAL_ITEMS = children.length;

  var _useState = useState(activeInitial),
      active = _useState[0],
      setActive = _useState[1];

  var _useState2 = useState(false),
      animating = _useState2[0],
      setAnimating = _useState2[1];

  var _useState3 = useState(false),
      reverseDirection = _useState3[0],
      setReverseDirection = _useState3[1];

  var childRefs = useRef([]);
  useEffect(function () {
    if (animating) {
      onTransitionOver();
    }
  }, [animating, onTransitionOver]);
  useInterval(function () {
    transitionToNext();
  }, delay);
  useEffect(function () {
    childRefs.current[activeInitial].scrollIntoView();
  }, [activeInitial]);
  var dots = [];
  children.forEach(function (_, idx) {
    childRefs.current = [].concat(childRefs.current, [createRef()]);

    if (!disableTracker) {
      dots = [].concat(dots, [/*#__PURE__*/React.createElement("div", {
        className: trackerDotClassName + " " + styles.dot + (active === idx ? " " + trackerDotActiveClassName + " " + styles.active : ''),
        onClick: function onClick() {
          return transitionToItem({
            idx: idx,
            elem: childRefs.current[idx]
          });
        },
        style: active === idx ? trackerDotActiveStyle : trackerDotStyle
      })]);
    }
  });

  var transitionToItem = function transitionToItem(_ref2) {
    var idx = _ref2.idx,
        elem = _ref2.elem;

    if (!animating && idx !== active) {
      onTransitionStart(active);
      setAnimating(true);
      setActive(idx);
      scrollIntoView(elem, {
        cancellable: false,
        time: speed
      }, function (type) {
        if (type === 'complete') {
          setAnimating(false);
          onTransitionEnd(idx);
        }
      });
    }
  };

  var transitionToPrev = function transitionToPrev() {
    var prevIdx = active;

    if (active - 1 < 0) {
      if (looping) {
        prevIdx = TOTAL_ITEMS - 1;
      }

      if (relay) {
        prevIdx = active + 1;
        setReverseDirection(true);
      }
    } else {
      if (reverseDirection) {
        if (active + 1 === TOTAL_ITEMS) {
          setReverseDirection(false);
          prevIdx = active - 1;
        } else {
          prevIdx = active + 1;
        }
      } else {
        prevIdx = active - 1;
      }
    }

    var prevElem = childRefs.current[prevIdx];
    transitionToItem({
      idx: prevIdx,
      elem: prevElem
    });
  };

  var transitionToNext = function transitionToNext() {
    var nextIdx = active;

    if (active + 1 === TOTAL_ITEMS) {
      if (looping) {
        nextIdx = 0;
      }

      if (relay) {
        nextIdx = active - 1;
        setReverseDirection(true);
      }
    } else {
      if (reverseDirection) {
        if (active - 1 < 0) {
          setReverseDirection(false);
          nextIdx = active + 1;
        } else {
          nextIdx = active - 1;
        }
      } else {
        nextIdx = active + 1;
      }
    }

    var nextElem = childRefs.current[nextIdx];
    transitionToItem({
      idx: nextIdx,
      elem: nextElem
    });
  };

  var trackScrolling = function trackScrolling(e) {
    if (e.deltaY < 0 || e.deltaX < 0) {
      transitionToPrev();
    } else if (e.deltaY > 0 || e.deltaX > 0) {
      transitionToNext();
    }
  };

  var trackDragging = function trackDragging(_, info) {
    if (!vertical && info.delta.x < 0 || vertical && info.delta.y < 0) {
      transitionToNext();
    } else {
      transitionToPrev();
    }
  };

  return /*#__PURE__*/React.createElement("div", {
    className: containerClassName + " " + styles.carousel,
    style: containerStyle
  }, /*#__PURE__*/React.createElement(motion.div, {
    onPanStart: panning ? trackDragging : null,
    className: className + " " + styles['carousel-items'] + (vertical ? " " + styles.vertical : ''),
    style: _extends({}, style, {
      height: height
    }),
    onWheel: !disableScroll ? trackScrolling : null
  }, looping && /*#__PURE__*/React.createElement("div", {
    className: styles.dummy,
    style: {
      height: "10px",
      width: "100%",
      marginBottom: 20
    }
  }), children.map(function (child, idx) {
    return /*#__PURE__*/React.createElement("div", {
      key: idx,
      className: itemContainerClassName + " " + styles['carousel-item'],
      style: _extends({}, itemContainerStyle, {
        height: height
      }),
      ref: function ref(el) {
        return childRefs.current[idx] = el;
      }
    }, child);
  }), looping && /*#__PURE__*/React.createElement("div", {
    className: styles.dummy,
    style: {
      height: "10px",
      width: "100%",
      marginBottom: 20
    }
  })), !disableTracker && /*#__PURE__*/React.createElement("div", {
    className: trackerClassName + " " + styles.tracker,
    style: trackerStyle
  }, dots));
};

SleekCarousel.defaultProps = {
  children: [],
  active: 0,
  onTransitionStart: function onTransitionStart() {},
  onTransitionOver: function onTransitionOver() {},
  onTransitionEnd: function onTransitionEnd() {},
  vertical: false,
  height: 500,
  disableTracker: false,
  disableScroll: false,
  delay: 3000,
  speed: 1500,
  looping: false,
  relay: false,
  panning: false,
  containerClassName: '',
  containerStyle: {},
  itemContainerClassName: '',
  itemContainerStyle: {},
  className: '',
  style: {},
  trackerClassName: '',
  trackerStyle: {},
  trackerDotClassName: '',
  trackerDotStyle: {},
  trackerDotActiveClassName: '',
  trackerDotActiveStyle: {}
};
SleekCarousel.propTypes = {
  children: PropTypes.arrayOf(PropTypes.element),
  active: PropTypes.number,
  onTransitionStart: PropTypes.func,
  onTransitionOver: PropTypes.func,
  onTransitionEnd: PropTypes.func,
  height: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
  vertical: PropTypes.bool,
  disableTracker: PropTypes.bool,
  disableScroll: PropTypes.bool,
  delay: PropTypes.number,
  speed: PropTypes.number,
  looping: PropTypes.bool,
  relay: PropTypes.bool,
  panning: PropTypes.bool,
  containerClassName: PropTypes.string,
  containerStyle: PropTypes.object,
  itemContainerClassName: PropTypes.string,
  itemContainerStyle: PropTypes.object,
  className: PropTypes.string,
  style: PropTypes.object,
  trackerClassName: PropTypes.string,
  trackerStyle: PropTypes.object,
  trackerDotClassName: PropTypes.string,
  trackerDotStyle: PropTypes.object,
  trackerDotActiveClassName: PropTypes.string,
  trackerDotActiveStyle: PropTypes.object
};

export default SleekCarousel;
//# sourceMappingURL=index.modern.js.map
